<?php declare(strict_types=1);

namespace BitBadger\PDODocument\Query;

use BitBadger\PDODocument\{DocumentException, Field, FieldMatch, Query};

/**
 * Queries for retrieving documents
 */
class Find
{
    /**
     * Query to retrieve a document by its ID
     *
     * @param string $tableName The name of the table from which a document should be retrieved
     * @return string The SELECT statement to retrieve a document by its ID
     * @throws DocumentException If the database mode has not been set
     */
    public static function byId(string $tableName): string
    {
        return Query::selectFromTable($tableName) . ' WHERE ' . Query::whereById();
    }

    /**
     * Query to retrieve documents using a comparison on JSON fields
     *
     * @param string $tableName The name of the table from which documents should be retrieved
     * @param Field[] $fields The field comparison to match
     * @param FieldMatch|null $match How to handle multiple conditions (optional; defaults to All)
     * @return string The SELECT statement to retrieve documents by field comparison
     * @throws DocumentException If the database mode has not been set
     */
    public static function byFields(string $tableName, array $fields, ?FieldMatch $match = null): string
    {
        return Query::selectFromTable($tableName) . ' WHERE ' . Query::whereByFields($fields, $match);
    }
}
